# RDFLib SPARQL DataFrame

Export results from an rdflib SPARQL query into a `pandas.DataFrame`, using Python types.

Taken from https://github.com/RDFLib/sparqlwrapper/issues/125#issuecomment-704291308 resp. https://github.com/RDFLib/rdflib/issues/1179#issuecomment-704299074 .
